@@ -800,15 +800,15 @@ class PatchTransform3D:
         """
         # get coordinates
         patch_space_dz = self.stride[0]/self.patch_shape[0]
+        z_start = patch_space_dz * int(self.stride[0]<self.patch_shape[0])
         patch_space_dy = self.stride[1]/self.patch_shape[1]
+        y_start = patch_space_dy * int(self.stride[1]<self.patch_shape[1])
         patch_space_dx = self.stride[2]/self.patch_shape[2]
-        Zs, Ys, Xs = np.meshgrid(np.arange(0,self.patch_space_shape[0],patch_space_dz),
-                                 np.arange(0,self.patch_space_shape[1],patch_space_dy),
-                                 np.arange(0,self.patch_space_shape[2],patch_space_dx))
+        x_start = patch_space_dx * int(self.stride[2]<self.patch_shape[2])
+        Zs, Ys, Xs = np.meshgrid(np.arange(z_start,self.patch_space_shape[0],patch_space_dz),
+                                 np.arange(y_start,self.patch_space_shape[1],patch_space_dy),
+                                 np.arange(x_start,self.patch_space_shape[2],patch_space_dx))
         ZYXs = np.vstack([Zs.flatten(), Ys.flatten(), Xs.flatten()]).transpose()
-
-        self.APP = ZYXs
-
         n_patches = len(ZYXs)
 
         # get necessary trace attributes before the hdf5 file is open
